@@ -100,3 +100,16 @@ RTC = 'RTC'
 CSLC = 'CSLC'
 RTC_STATIC = 'RTC-STATIC'
 CSLC_STATIC = 'CSLC-STATIC'
+DISP_S1 = 'DISP-S1'
+
+# NISAR
+L0B = 'L0B'
+RSLC = 'RSLC'
+RIFG = 'RIFG'
+RUNW = 'RUNW'
+ROFF = 'ROFF'
+GSLC = 'GSLC'
+GCOV = 'GCOV'
+GUNW = 'GUNW'
+GOFF = 'GOFF'
+SME2 = 'SME2'
